Captain Claw

Tools
Skills
Chat 0 messages
Drop CSV or XLSX to import into datastore
🦀
Welcome to Captain Claw
Type a message to start a conversation, or use a `/command`.
Press `Ctrl+K` for the command palette. Press `?` button for help.
Monitor
📊
Tool outputs and traces will appear here
Script mode
`Enter` send `Shift+Enter` new line `Ctrl+K` commands `Ctrl+N` new session `Esc` cancel
🔒

### Approval Required

-

### Read Folders

Active folders
No extra folders configured
Browse & add folder
Loading...
-
Active Google Drive folders
No Google Drive folders configured
Browse & add folder
Loading...
My Drive
-